@@ -43,6 +43,11 @@
 #define min(a,b) (a<b?a:b)
 #define max(a,b) (a>b?a:b)
 
+// For platforms without PATH_MAX
+#ifndef PATH_MAX
+#define PATH_MAX 4096
+#endif
+
 //pid of the controlled process
 int pid=0;
 //executable file name
